@@ -1,4 +1,6 @@
-require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')
+#!/usr/bin/env rspec
+
+require 'spec_helper'
 
 describe "Hostname facts" do
 
