@@ -1,10 +1,8 @@
-#!/usr/bin/env ruby
-
-require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')
+#!/usr/bin/env rspec
 
+require 'spec_helper'
 require 'facter/util/loader'
 
-
 # loader subclass for making assertions about file/directory ordering
 class TestLoader < Facter::Util::Loader
   def loaded_files
