@@ -1,6 +1,6 @@
-require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')
+#!/usr/bin/env rspec
 
-require 'facter'
+require 'spec_helper'
 require 'facter/util/virtual'
 require 'facter/util/macosx'
 
@@ -112,6 +112,25 @@ describe "Virtual fact" do
       Facter.fact(:virtual).value.should == "vmware"
     end
 
+    it "should be xen0 with xen dom0 files in /proc" do
+      Facter.fact(:kernel).stubs(:value).returns("Linux")
+      Facter.fact(:operatingsystem).stubs(:value).returns("Linux")
+      Facter.fact(:hardwaremodel).stubs(:value).returns("i386")
+      Facter::Util::Virtual.expects(:xen?).returns(true)
+      FileTest.expects(:exists?).with("/proc/xen/xsd_kva").returns(true)
+      Facter.fact(:virtual).value.should == "xen0"
+    end
+
+    it "should be xenu with xen domU files in /proc" do
+      Facter.fact(:kernel).stubs(:value).returns("Linux")
+      Facter.fact(:operatingsystem).stubs(:value).returns("Linux")
+      Facter.fact(:hardwaremodel).stubs(:value).returns("i386")
+      Facter::Util::Virtual.expects(:xen?).returns(true)
+      FileTest.expects(:exists?).with("/proc/xen/xsd_kva").returns(false)
+      FileTest.expects(:exists?).with("/proc/xen/capabilities").returns(true)
+      Facter.fact(:virtual).value.should == "xenu"
+    end
+
     it "should be xenhvm with Xen HVM vendor name from lspci" do
       Facter.fact(:kernel).stubs(:value).returns("Linux")
       Facter::Util::Resolution.stubs(:exec).with('lspci').returns("00:03.0 Unassigned class [ff80]: XenSource, Inc. Xen Platform Device (rev 01)")
@@ -184,24 +203,35 @@ describe "Virtual fact" do
       Facter::Util::Resolution.stubs(:exec).with('prtdiag').returns("System Configuration: innotek GmbH VirtualBox")
       Facter.fact(:virtual).value.should == "virtualbox"
     end
+  end
 
-    it "should be xen0 with xen dom0 files in /proc" do
-      Facter.fact(:kernel).stubs(:value).returns("Linux")
-      Facter.fact(:operatingsystem).stubs(:value).returns("Linux")
-      Facter.fact(:hardwaremodel).stubs(:value).returns("i386")
-      Facter::Util::Virtual.expects(:xen?).returns(true)
-      FileTest.expects(:exists?).with("/proc/xen/xsd_kva").returns(true)
-      Facter.fact(:virtual).value.should == "xen0"
+  describe "on OpenBSD" do
+    before do
+      Facter::Util::Resolution.stubs(:exec).with("vmware -v").returns false
+      Facter.fact(:kernel).stubs(:value).returns("OpenBSD")
+      Facter.fact(:hardwaremodel).stubs(:value).returns(nil)
+      Facter::Util::Resolution.stubs(:exec).with('lspci').returns(nil)
+      Facter::Util::Resolution.stubs(:exec).with('dmidecode').returns(nil)
     end
-    
-    it "should be xenu with xen domU files in /proc" do
-      Facter.fact(:kernel).stubs(:value).returns("Linux")
-      Facter.fact(:operatingsystem).stubs(:value).returns("Linux")
-      Facter.fact(:hardwaremodel).stubs(:value).returns("i386")
-      Facter::Util::Virtual.expects(:xen?).returns(true)
-      FileTest.expects(:exists?).with("/proc/xen/xsd_kva").returns(false)
-      FileTest.expects(:exists?).with("/proc/xen/capabilities").returns(true)
-      Facter.fact(:virtual).value.should == "xenu"
+
+    it "should be parallels with Parallels product name from sysctl" do
+      Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.product 2>/dev/null').returns("Parallels Virtual Platform")
+      Facter.fact(:virtual).value.should == "parallels"
+    end
+
+    it "should be vmware with VMware product name from sysctl" do
+      Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.product 2>/dev/null').returns("VMware Virtual Platform")
+      Facter.fact(:virtual).value.should == "vmware"
+    end
+
+    it "should be virtualbox with VirtualBox product name from sysctl" do
+      Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.product 2>/dev/null').returns("VirtualBox")
+      Facter.fact(:virtual).value.should == "virtualbox"
+    end
+
+    it "should be xenhvm with Xen HVM product name from sysctl" do
+      Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.product 2>/dev/null').returns("HVM domU")
+      Facter.fact(:virtual).value.should == "xenhvm"
     end
   end
 end
